import sys
import os
from progress.bar import Bar
from jinja2 import Environment, FileSystemLoader
import subprocess

def argument_parsing():
    if (len(sys.argv) < 2):
        print("error: missing argument", file=sys.stderr)
        exit(1)
    return sys.argv[1]

def get_exif(files, raw):
    exifs: list[str] = [file for file in files if file.endswith(".exif")]
    exif: str
    if len(exifs) > 0:
        exif = exifs[0]
    elif (raw is not None):
        exif = raw[:-3] + "exif"
        if os.system(f"exiftool {raw} > {exif}"):
            os.remove(exif)
            exif = None
    else:
        exif = None 
    return exif

def get_images(files):
    images_datas: list[str] = []
    images: list[str] = [file for file in files if os.path.isfile(file) and file.endswith(".png")]
    for image in images:
        export_data_file: str = image + ".out.pp3"
        if (os.path.exists(export_data_file) and os.path.isfile(export_data_file)):
            images_datas.append((image, export_data_file))
        images_datas.append((image,))
    return images_datas
    

def main():
    site_path: str = argument_parsing()
    folders: list[str] = [os.path.join(site_path, f) for f in os.listdir(site_path)]
    folders = [file for file in folders if os.path.isdir(file)]
    with Bar("generating...", max=len(folders)) as bar:
        for folder in folders:
            files: list[str] = [os.path.join(folder, file) for file in os.listdir(folder)]
            images: list[str] = get_images(files)
            raws: list[str] = [file for file in files if file.endswith(".NEF")]
            raw: str = raws[0] if len(raws) > 0 else None
            exif: str = get_exif(files, raw)
            readmes: list[str] = [file for file in files if file == "readme.md"]
            readme: str = readmes[0] if len(readmes) > 0 else None
            bar.next()


if __name__ == "__main__":
    main()